@@ -5,6 +5,7 @@ from connect.autogen import connect_logger_Logger as Logger
 from connect.autogen import connect_logger_LoggerConfig as LoggerConfig
 from connect.autogen import connect_logger_LoggerHandler as LoggerHandler
 from connect.autogen import connect_logger_MarkdownLoggerFormatter as MarkdownLoggerFormatter
+from connect.autogen import connect_logger_PlainLoggerFormatter as PlainLoggerFormatter
 
 
 __all__ = [
@@ -15,4 +16,5 @@ __all__ = [
     'LoggerConfig',
     'LoggerHandler',
     'MarkdownLoggerFormatter',
+    'PlainLoggerFormatter',
 ]
